# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetHaVipResult',
    'AwaitableGetHaVipResult',
    'get_ha_vip',
    'get_ha_vip_output',
]

@pulumi.output_type
class GetHaVipResult:
    """
    A collection of values returned by getHaVip.
    """
    def __init__(__self__, associated_eip_address=None, associated_eip_id=None, associated_instance_ids=None, associated_instance_type=None, created_at=None, description=None, ha_vip_id=None, ha_vip_name=None, id=None, ip_address=None, master_instance_id=None, project_name=None, status=None, subnet_id=None, tags=None, updated_at=None, vpc_id=None):
        if associated_eip_address and not isinstance(associated_eip_address, str):
            raise TypeError("Expected argument 'associated_eip_address' to be a str")
        pulumi.set(__self__, "associated_eip_address", associated_eip_address)
        if associated_eip_id and not isinstance(associated_eip_id, str):
            raise TypeError("Expected argument 'associated_eip_id' to be a str")
        pulumi.set(__self__, "associated_eip_id", associated_eip_id)
        if associated_instance_ids and not isinstance(associated_instance_ids, list):
            raise TypeError("Expected argument 'associated_instance_ids' to be a list")
        pulumi.set(__self__, "associated_instance_ids", associated_instance_ids)
        if associated_instance_type and not isinstance(associated_instance_type, str):
            raise TypeError("Expected argument 'associated_instance_type' to be a str")
        pulumi.set(__self__, "associated_instance_type", associated_instance_type)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if ha_vip_id and not isinstance(ha_vip_id, str):
            raise TypeError("Expected argument 'ha_vip_id' to be a str")
        pulumi.set(__self__, "ha_vip_id", ha_vip_id)
        if ha_vip_name and not isinstance(ha_vip_name, str):
            raise TypeError("Expected argument 'ha_vip_name' to be a str")
        pulumi.set(__self__, "ha_vip_name", ha_vip_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if master_instance_id and not isinstance(master_instance_id, str):
            raise TypeError("Expected argument 'master_instance_id' to be a str")
        pulumi.set(__self__, "master_instance_id", master_instance_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="associatedEipAddress")
    def associated_eip_address(self) -> builtins.str:
        """
        HAVIP绑定的公网IP的IP地址。
        """
        return pulumi.get(self, "associated_eip_address")

    @property
    @pulumi.getter(name="associatedEipId")
    def associated_eip_id(self) -> builtins.str:
        """
        HAVIP绑定的公网IP的ID。
        """
        return pulumi.get(self, "associated_eip_id")

    @property
    @pulumi.getter(name="associatedInstanceIds")
    def associated_instance_ids(self) -> Sequence[builtins.str]:
        """
        绑定HAVIP的实例ID列表。
        """
        return pulumi.get(self, "associated_instance_ids")

    @property
    @pulumi.getter(name="associatedInstanceType")
    def associated_instance_type(self) -> builtins.str:
        """
        绑定HAVIP的实例类型。EcsInstance：云服务器实例。NetworkInterface：弹性网卡。
        """
        return pulumi.get(self, "associated_instance_type")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        HAVIP的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        HAVIP的描述。长度限制为0～255个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="haVipId")
    def ha_vip_id(self) -> builtins.str:
        """
        HAVIP的ID。
        """
        return pulumi.get(self, "ha_vip_id")

    @property
    @pulumi.getter(name="haVipName")
    def ha_vip_name(self) -> builtins.str:
        """
        HAVIP的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制在0～128字符之间。
        """
        return pulumi.get(self, "ha_vip_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        HAVIP的IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="masterInstanceId")
    def master_instance_id(self) -> builtins.str:
        """
        与HAVIP绑定的主实例的ID。
        """
        return pulumi.get(self, "master_instance_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        HAVIP的项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        HAVIP的状态。Available：可用。Creating：创建中。InUse：使用中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        HAVIP所属的子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetHaVipTagResult']:
        """
        HAVIP所属标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        HAVIP最近一次的修改时间。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        HAVIP所属的VPC ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetHaVipResult(GetHaVipResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHaVipResult(
            associated_eip_address=self.associated_eip_address,
            associated_eip_id=self.associated_eip_id,
            associated_instance_ids=self.associated_instance_ids,
            associated_instance_type=self.associated_instance_type,
            created_at=self.created_at,
            description=self.description,
            ha_vip_id=self.ha_vip_id,
            ha_vip_name=self.ha_vip_name,
            id=self.id,
            ip_address=self.ip_address,
            master_instance_id=self.master_instance_id,
            project_name=self.project_name,
            status=self.status,
            subnet_id=self.subnet_id,
            tags=self.tags,
            updated_at=self.updated_at,
            vpc_id=self.vpc_id)


def get_ha_vip(id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHaVipResult:
    """
    Data Source schema for Byteplus::VPC::HAVIP


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getHaVip:getHaVip', __args__, opts=opts, typ=GetHaVipResult).value

    return AwaitableGetHaVipResult(
        associated_eip_address=pulumi.get(__ret__, 'associated_eip_address'),
        associated_eip_id=pulumi.get(__ret__, 'associated_eip_id'),
        associated_instance_ids=pulumi.get(__ret__, 'associated_instance_ids'),
        associated_instance_type=pulumi.get(__ret__, 'associated_instance_type'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        ha_vip_id=pulumi.get(__ret__, 'ha_vip_id'),
        ha_vip_name=pulumi.get(__ret__, 'ha_vip_name'),
        id=pulumi.get(__ret__, 'id'),
        ip_address=pulumi.get(__ret__, 'ip_address'),
        master_instance_id=pulumi.get(__ret__, 'master_instance_id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_ha_vip_output(id: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHaVipResult]:
    """
    Data Source schema for Byteplus::VPC::HAVIP


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getHaVip:getHaVip', __args__, opts=opts, typ=GetHaVipResult)
    return __ret__.apply(lambda __response__: GetHaVipResult(
        associated_eip_address=pulumi.get(__response__, 'associated_eip_address'),
        associated_eip_id=pulumi.get(__response__, 'associated_eip_id'),
        associated_instance_ids=pulumi.get(__response__, 'associated_instance_ids'),
        associated_instance_type=pulumi.get(__response__, 'associated_instance_type'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        ha_vip_id=pulumi.get(__response__, 'ha_vip_id'),
        ha_vip_name=pulumi.get(__response__, 'ha_vip_name'),
        id=pulumi.get(__response__, 'id'),
        ip_address=pulumi.get(__response__, 'ip_address'),
        master_instance_id=pulumi.get(__response__, 'master_instance_id'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NlbSecurityPolicyArgs', 'NlbSecurityPolicy']

@pulumi.input_type
class NlbSecurityPolicyArgs:
    def __init__(__self__, *,
                 ciphers: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 tls_versions: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]] = None):
        """
        The set of arguments for constructing a NlbSecurityPolicy resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ciphers: TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: 更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        :param pulumi.Input[builtins.str] project_name: TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        :param pulumi.Input[builtins.str] security_policy_name: 安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        """
        pulumi.set(__self__, "ciphers", ciphers)
        pulumi.set(__self__, "tls_versions", tls_versions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_policy_name is not None:
            pulumi.set(__self__, "security_policy_name", security_policy_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def ciphers(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        """
        return pulumi.get(self, "ciphers")

    @ciphers.setter
    def ciphers(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "ciphers", value)

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        """
        return pulumi.get(self, "tls_versions")

    @tls_versions.setter
    def tls_versions(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "tls_versions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityPolicyName")
    def security_policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        """
        return pulumi.get(self, "security_policy_name")

    @security_policy_name.setter
    def security_policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_policy_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NlbSecurityPolicyState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 related_listener_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NlbSecurityPolicy resources.
        :param pulumi.Input[builtins.str] account_id: TLS 安全策略所属的账号ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ciphers: TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] project_name: TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] related_listener_ids: TLS 安全策略关联的监听器。
        :param pulumi.Input[builtins.str] security_policy_id: 安全策略ID。
        :param pulumi.Input[builtins.str] security_policy_name: 安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        :param pulumi.Input[builtins.str] status: TLS 自定义安全策略状态。Creating：创建中。Configuring：配置中。Active：正常。Deleting：删除中。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: 更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if ciphers is not None:
            pulumi.set(__self__, "ciphers", ciphers)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if related_listener_ids is not None:
            pulumi.set(__self__, "related_listener_ids", related_listener_ids)
        if security_policy_id is not None:
            pulumi.set(__self__, "security_policy_id", security_policy_id)
        if security_policy_name is not None:
            pulumi.set(__self__, "security_policy_name", security_policy_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tls_versions is not None:
            pulumi.set(__self__, "tls_versions", tls_versions)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS 安全策略所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def ciphers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        """
        return pulumi.get(self, "ciphers")

    @ciphers.setter
    def ciphers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ciphers", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="relatedListenerIds")
    def related_listener_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        TLS 安全策略关联的监听器。
        """
        return pulumi.get(self, "related_listener_ids")

    @related_listener_ids.setter
    def related_listener_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "related_listener_ids", value)

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全策略ID。
        """
        return pulumi.get(self, "security_policy_id")

    @security_policy_id.setter
    def security_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_policy_id", value)

    @property
    @pulumi.getter(name="securityPolicyName")
    def security_policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        """
        return pulumi.get(self, "security_policy_name")

    @security_policy_name.setter
    def security_policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_policy_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS 自定义安全策略状态。Creating：创建中。Configuring：配置中。Active：正常。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbSecurityPolicyTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        """
        return pulumi.get(self, "tls_versions")

    @tls_versions.setter
    def tls_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tls_versions", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:clb/nlbSecurityPolicy:NlbSecurityPolicy")
class NlbSecurityPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbSecurityPolicyTagArgs', 'NlbSecurityPolicyTagArgsDict']]]]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        基于一些常见的场景，为您预置了一些安全策略，若系统预置的策略不满足您的需求，您还可以自定义安全策略。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_lbnlb_security_policy_demo = bytepluscc.clb.NlbSecurityPolicy("CLBNLBSecurityPolicyDemo",
            ciphers=[
                "TLS_AES_128_CCM_SHA256",
                "TLS_AES_128_GCM_SHA256",
            ],
            project_name="default",
            security_policy_name="ccapi-test-1",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            tls_versions=["TLSv1.3"])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbSecurityPolicy:NlbSecurityPolicy example "security_policy_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ciphers: TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        :param pulumi.Input[builtins.str] project_name: TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        :param pulumi.Input[builtins.str] security_policy_name: 安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: 更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NlbSecurityPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        基于一些常见的场景，为您预置了一些安全策略，若系统预置的策略不满足您的需求，您还可以自定义安全策略。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_lbnlb_security_policy_demo = bytepluscc.clb.NlbSecurityPolicy("CLBNLBSecurityPolicyDemo",
            ciphers=[
                "TLS_AES_128_CCM_SHA256",
                "TLS_AES_128_GCM_SHA256",
            ],
            project_name="default",
            security_policy_name="ccapi-test-1",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            tls_versions=["TLSv1.3"])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbSecurityPolicy:NlbSecurityPolicy example "security_policy_id"
        ```

        :param str resource_name: The name of the resource.
        :param NlbSecurityPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NlbSecurityPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbSecurityPolicyTagArgs', 'NlbSecurityPolicyTagArgsDict']]]]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NlbSecurityPolicyArgs.__new__(NlbSecurityPolicyArgs)

            if ciphers is None and not opts.urn:
                raise TypeError("Missing required property 'ciphers'")
            __props__.__dict__["ciphers"] = ciphers
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["security_policy_name"] = security_policy_name
            __props__.__dict__["tags"] = tags
            if tls_versions is None and not opts.urn:
                raise TypeError("Missing required property 'tls_versions'")
            __props__.__dict__["tls_versions"] = tls_versions
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["related_listener_ids"] = None
            __props__.__dict__["security_policy_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(NlbSecurityPolicy, __self__).__init__(
            'bytepluscc:clb/nlbSecurityPolicy:NlbSecurityPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            ciphers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            related_listener_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
            security_policy_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbSecurityPolicyTagArgs', 'NlbSecurityPolicyTagArgsDict']]]]] = None,
            tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'NlbSecurityPolicy':
        """
        Get an existing NlbSecurityPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: TLS 安全策略所属的账号ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ciphers: TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] project_name: TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] related_listener_ids: TLS 安全策略关联的监听器。
        :param pulumi.Input[builtins.str] security_policy_id: 安全策略ID。
        :param pulumi.Input[builtins.str] security_policy_name: 安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        :param pulumi.Input[builtins.str] status: TLS 自定义安全策略状态。Creating：创建中。Configuring：配置中。Active：正常。Deleting：删除中。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: 更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NlbSecurityPolicyState.__new__(_NlbSecurityPolicyState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["ciphers"] = ciphers
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["related_listener_ids"] = related_listener_ids
        __props__.__dict__["security_policy_id"] = security_policy_id
        __props__.__dict__["security_policy_name"] = security_policy_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tls_versions"] = tls_versions
        __props__.__dict__["updated_time"] = updated_time
        return NlbSecurityPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        TLS 安全策略所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def ciphers(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        """
        return pulumi.get(self, "ciphers")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="relatedListenerIds")
    def related_listener_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        TLS 安全策略关联的监听器。
        """
        return pulumi.get(self, "related_listener_ids")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> pulumi.Output[builtins.str]:
        """
        安全策略ID。
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="securityPolicyName")
    def security_policy_name(self) -> pulumi.Output[builtins.str]:
        """
        安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        """
        return pulumi.get(self, "security_policy_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        TLS 自定义安全策略状态。Creating：创建中。Configuring：配置中。Active：正常。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NlbSecurityPolicyTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        """
        return pulumi.get(self, "tls_versions")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetMountPointResult',
    'AwaitableGetMountPointResult',
    'get_mount_point',
    'get_mount_point_output',
]

@pulumi.output_type
class GetMountPointResult:
    """
    A collection of values returned by getMountPoint.
    """
    def __init__(__self__, clients=None, created_time=None, domain=None, file_system_id=None, id=None, ip=None, mount_point_id=None, mount_point_name=None, permission_group=None, permission_group_id=None, status=None, subnet_id=None, subnet_name=None, updated_time=None, vpc_id=None, vpc_name=None):
        if clients and not isinstance(clients, list):
            raise TypeError("Expected argument 'clients' to be a list")
        pulumi.set(__self__, "clients", clients)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if file_system_id and not isinstance(file_system_id, str):
            raise TypeError("Expected argument 'file_system_id' to be a str")
        pulumi.set(__self__, "file_system_id", file_system_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if mount_point_id and not isinstance(mount_point_id, str):
            raise TypeError("Expected argument 'mount_point_id' to be a str")
        pulumi.set(__self__, "mount_point_id", mount_point_id)
        if mount_point_name and not isinstance(mount_point_name, str):
            raise TypeError("Expected argument 'mount_point_name' to be a str")
        pulumi.set(__self__, "mount_point_name", mount_point_name)
        if permission_group and not isinstance(permission_group, dict):
            raise TypeError("Expected argument 'permission_group' to be a dict")
        pulumi.set(__self__, "permission_group", permission_group)
        if permission_group_id and not isinstance(permission_group_id, str):
            raise TypeError("Expected argument 'permission_group_id' to be a str")
        pulumi.set(__self__, "permission_group_id", permission_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if subnet_name and not isinstance(subnet_name, str):
            raise TypeError("Expected argument 'subnet_name' to be a str")
        pulumi.set(__self__, "subnet_name", subnet_name)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name and not isinstance(vpc_name, str):
            raise TypeError("Expected argument 'vpc_name' to be a str")
        pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def clients(self) -> Sequence['outputs.GetMountPointClientResult']:
        """
        客户端信息。
        """
        return pulumi.get(self, "clients")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        挂载点创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        DNS 地址。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> builtins.str:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        挂载点地址。
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> builtins.str:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> builtins.str:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @property
    @pulumi.getter(name="permissionGroup")
    def permission_group(self) -> 'outputs.GetMountPointPermissionGroupResult':
        """
        挂载点绑定的权限组信息。
        """
        return pulumi.get(self, "permission_group")

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> builtins.str:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> builtins.str:
        """
        子网名称。
        """
        return pulumi.get(self, "subnet_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        挂载点更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> builtins.str:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")


class AwaitableGetMountPointResult(GetMountPointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMountPointResult(
            clients=self.clients,
            created_time=self.created_time,
            domain=self.domain,
            file_system_id=self.file_system_id,
            id=self.id,
            ip=self.ip,
            mount_point_id=self.mount_point_id,
            mount_point_name=self.mount_point_name,
            permission_group=self.permission_group,
            permission_group_id=self.permission_group_id,
            status=self.status,
            subnet_id=self.subnet_id,
            subnet_name=self.subnet_name,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id,
            vpc_name=self.vpc_name)


def get_mount_point(id: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMountPointResult:
    """
    Data Source schema for Byteplus::FileNAS::MountPoint


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:filenas/getMountPoint:getMountPoint', __args__, opts=opts, typ=GetMountPointResult).value

    return AwaitableGetMountPointResult(
        clients=pulumi.get(__ret__, 'clients'),
        created_time=pulumi.get(__ret__, 'created_time'),
        domain=pulumi.get(__ret__, 'domain'),
        file_system_id=pulumi.get(__ret__, 'file_system_id'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        mount_point_id=pulumi.get(__ret__, 'mount_point_id'),
        mount_point_name=pulumi.get(__ret__, 'mount_point_name'),
        permission_group=pulumi.get(__ret__, 'permission_group'),
        permission_group_id=pulumi.get(__ret__, 'permission_group_id'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        subnet_name=pulumi.get(__ret__, 'subnet_name'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpc_name=pulumi.get(__ret__, 'vpc_name'))
def get_mount_point_output(id: Optional[pulumi.Input[builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMountPointResult]:
    """
    Data Source schema for Byteplus::FileNAS::MountPoint


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:filenas/getMountPoint:getMountPoint', __args__, opts=opts, typ=GetMountPointResult)
    return __ret__.apply(lambda __response__: GetMountPointResult(
        clients=pulumi.get(__response__, 'clients'),
        created_time=pulumi.get(__response__, 'created_time'),
        domain=pulumi.get(__response__, 'domain'),
        file_system_id=pulumi.get(__response__, 'file_system_id'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        mount_point_id=pulumi.get(__response__, 'mount_point_id'),
        mount_point_name=pulumi.get(__response__, 'mount_point_name'),
        permission_group=pulumi.get(__response__, 'permission_group'),
        permission_group_id=pulumi.get(__response__, 'permission_group_id'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        subnet_name=pulumi.get(__response__, 'subnet_name'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpc_name=pulumi.get(__response__, 'vpc_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 compute_spec: pulumi.Input[builtins.str],
                 storage_space: pulumi.Input[builtins.int],
                 subnet_id: pulumi.Input[builtins.str],
                 user_name: pulumi.Input[builtins.str],
                 user_password: pulumi.Input[builtins.str],
                 version: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 charge_detail: Optional[pulumi.Input['InstanceChargeDetailArgs']] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        """
        pulumi.set(__self__, "compute_spec", compute_spec)
        pulumi.set(__self__, "storage_space", storage_space)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "user_name", user_name)
        pulumi.set(__self__, "user_password", user_password)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if charge_detail is not None:
            pulumi.set(__self__, "charge_detail", charge_detail)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @compute_spec.setter
    def compute_spec(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "compute_spec", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Input[builtins.int]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Input[builtins.str]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_password", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[builtins.str]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> Optional[pulumi.Input['InstanceChargeDetailArgs']]:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: Optional[pulumi.Input['InstanceChargeDetailArgs']]):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 apply_private_dns_to_public: Optional[pulumi.Input[builtins.bool]] = None,
                 arch_type: Optional[pulumi.Input[builtins.str]] = None,
                 charge_detail: Optional[pulumi.Input['InstanceChargeDetailArgs']] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_status: Optional[pulumi.Input[builtins.str]] = None,
                 is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]] = None,
                 used_storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_description: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[builtins.str] account_id: 创建实例的主账号ID。
        :param pulumi.Input[builtins.bool] apply_private_dns_to_public: 是否已开启公网解析功能。true：已开启, false：已关闭
        :param pulumi.Input[builtins.str] arch_type: 实例的类型，即集群版或单机版。
        :param pulumi.Input['InstanceChargeDetailArgs'] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_id: RabbitMQ 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否开启了云盘加密。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.int] used_storage_space: 实例已用存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_description: 可用区的描述信息。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if apply_private_dns_to_public is not None:
            pulumi.set(__self__, "apply_private_dns_to_public", apply_private_dns_to_public)
        if arch_type is not None:
            pulumi.set(__self__, "arch_type", arch_type)
        if charge_detail is not None:
            pulumi.set(__self__, "charge_detail", charge_detail)
        if compute_spec is not None:
            pulumi.set(__self__, "compute_spec", compute_spec)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if instance_description is not None:
            pulumi.set(__self__, "instance_description", instance_description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_status is not None:
            pulumi.set(__self__, "instance_status", instance_status)
        if is_encrypted is not None:
            pulumi.set(__self__, "is_encrypted", is_encrypted)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if storage_space is not None:
            pulumi.set(__self__, "storage_space", storage_space)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if used_storage_space is not None:
            pulumi.set(__self__, "used_storage_space", used_storage_space)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if user_password is not None:
            pulumi.set(__self__, "user_password", user_password)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_description is not None:
            pulumi.set(__self__, "zone_description", zone_description)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建实例的主账号ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="applyPrivateDnsToPublic")
    def apply_private_dns_to_public(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否已开启公网解析功能。true：已开启, false：已关闭
        """
        return pulumi.get(self, "apply_private_dns_to_public")

    @apply_private_dns_to_public.setter
    def apply_private_dns_to_public(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "apply_private_dns_to_public", value)

    @property
    @pulumi.getter(name="archType")
    def arch_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的类型，即集群版或单机版。
        """
        return pulumi.get(self, "arch_type")

    @arch_type.setter
    def arch_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "arch_type", value)

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> Optional[pulumi.Input['InstanceChargeDetailArgs']]:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @charge_detail.setter
    def charge_detail(self, value: Optional[pulumi.Input['InstanceChargeDetailArgs']]):
        pulumi.set(self, "charge_detail", value)

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @compute_spec.setter
    def compute_spec(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "compute_spec", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]:
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceEndpointArgs']]]]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @instance_description.setter
    def instance_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @instance_status.setter
    def instance_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_status", value)

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启了云盘加密。
        """
        return pulumi.get(self, "is_encrypted")

    @is_encrypted.setter
    def is_encrypted(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_encrypted", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @storage_space.setter
    def storage_space(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "storage_space", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="usedStorageSpace")
    def used_storage_space(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例已用存储空间。单位为 GiB。
        """
        return pulumi.get(self, "used_storage_space")

    @used_storage_space.setter
    def used_storage_space(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_storage_space", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @user_password.setter
    def user_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_password", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneDescription")
    def zone_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        可用区的描述信息。
        """
        return pulumi.get(self, "zone_description")

    @zone_description.setter
    def zone_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_description", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:rabbitmq/instance:Instance")
class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        消息队列 RabbitMQ版是一款支持 AMQP（Advanced Message Queuing Protocol） 协议的分布式高可用消息队列产品，完全兼容 RabbitMQ 开源生态及多语言客户端，提供丰富的消息特性和灵活的消息路由，同时具备分布式、高吞吐、低延迟、灵活扩展的云消息服务优势，无需用户部署运维，能够轻松实现快速上云。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        消息队列 RabbitMQ版是一款支持 AMQP（Advanced Message Queuing Protocol） 协议的分布式高可用消息队列产品，完全兼容 RabbitMQ 开源生态及多语言客户端，提供丰富的消息特性和灵活的消息路由，同时具备分布式、高吞吐、低延迟、灵活扩展的云消息服务优势，无需用户部署运维，能够轻松实现快速上云。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instance:Instance example "instance_id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
                 compute_spec: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_space: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_password: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["charge_detail"] = charge_detail
            if compute_spec is None and not opts.urn:
                raise TypeError("Missing required property 'compute_spec'")
            __props__.__dict__["compute_spec"] = compute_spec
            __props__.__dict__["eip_id"] = eip_id
            __props__.__dict__["instance_description"] = instance_description
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["project_name"] = project_name
            if storage_space is None and not opts.urn:
                raise TypeError("Missing required property 'storage_space'")
            __props__.__dict__["storage_space"] = storage_space
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
            if user_password is None and not opts.urn:
                raise TypeError("Missing required property 'user_password'")
            __props__.__dict__["user_password"] = user_password
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["apply_private_dns_to_public"] = None
            __props__.__dict__["arch_type"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["endpoints"] = None
            __props__.__dict__["instance_id"] = None
            __props__.__dict__["instance_status"] = None
            __props__.__dict__["is_encrypted"] = None
            __props__.__dict__["used_storage_space"] = None
            __props__.__dict__["zone_description"] = None
        super(Instance, __self__).__init__(
            'bytepluscc:rabbitmq/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            apply_private_dns_to_public: Optional[pulumi.Input[builtins.bool]] = None,
            arch_type: Optional[pulumi.Input[builtins.str]] = None,
            charge_detail: Optional[pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']]] = None,
            compute_spec: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceEndpointArgs', 'InstanceEndpointArgsDict']]]]] = None,
            instance_description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_status: Optional[pulumi.Input[builtins.str]] = None,
            is_encrypted: Optional[pulumi.Input[builtins.bool]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            storage_space: Optional[pulumi.Input[builtins.int]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceTagArgs', 'InstanceTagArgsDict']]]]] = None,
            used_storage_space: Optional[pulumi.Input[builtins.int]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None,
            user_password: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_description: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 创建实例的主账号ID。
        :param pulumi.Input[builtins.bool] apply_private_dns_to_public: 是否已开启公网解析功能。true：已开启, false：已关闭
        :param pulumi.Input[builtins.str] arch_type: 实例的类型，即集群版或单机版。
        :param pulumi.Input[Union['InstanceChargeDetailArgs', 'InstanceChargeDetailArgsDict']] charge_detail: 实例的计费方式等计费信息。
        :param pulumi.Input[builtins.str] compute_spec: RabbitMQ实例的计算规格。
        :param pulumi.Input[builtins.str] created_time: 实例的创建时间。
        :param pulumi.Input[builtins.str] eip_id: EIP的ID。
        :param pulumi.Input[builtins.str] instance_description: 实例的简单描述。
        :param pulumi.Input[builtins.str] instance_id: RabbitMQ 实例 ID。
        :param pulumi.Input[builtins.str] instance_name: RabbitMQ 实例名称。
        :param pulumi.Input[builtins.str] instance_status: 实例状态。
        :param pulumi.Input[builtins.bool] is_encrypted: 是否开启了云盘加密。
        :param pulumi.Input[builtins.str] project_name: 实例所属的IAM项目。
        :param pulumi.Input[builtins.int] storage_space: 实例总存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] subnet_id: VPC的子网ID。
        :param pulumi.Input[builtins.int] used_storage_space: 实例已用存储空间。单位为 GiB。
        :param pulumi.Input[builtins.str] user_name: RabbitMQ WebUI管理员账号名。
        :param pulumi.Input[builtins.str] user_password: RabbitMQ WebUI管理员密码。
        :param pulumi.Input[builtins.str] version: 支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络（VPC）ID。
        :param pulumi.Input[builtins.str] zone_description: 可用区的描述信息。
        :param pulumi.Input[builtins.str] zone_id: 实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["apply_private_dns_to_public"] = apply_private_dns_to_public
        __props__.__dict__["arch_type"] = arch_type
        __props__.__dict__["charge_detail"] = charge_detail
        __props__.__dict__["compute_spec"] = compute_spec
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["instance_description"] = instance_description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_status"] = instance_status
        __props__.__dict__["is_encrypted"] = is_encrypted
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["storage_space"] = storage_space
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["used_storage_space"] = used_storage_space
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["user_password"] = user_password
        __props__.__dict__["version"] = version
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_description"] = zone_description
        __props__.__dict__["zone_id"] = zone_id
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        创建实例的主账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="applyPrivateDnsToPublic")
    def apply_private_dns_to_public(self) -> pulumi.Output[builtins.bool]:
        """
        是否已开启公网解析功能。true：已开启, false：已关闭
        """
        return pulumi.get(self, "apply_private_dns_to_public")

    @property
    @pulumi.getter(name="archType")
    def arch_type(self) -> pulumi.Output[builtins.str]:
        """
        实例的类型，即集群版或单机版。
        """
        return pulumi.get(self, "arch_type")

    @property
    @pulumi.getter(name="chargeDetail")
    def charge_detail(self) -> pulumi.Output['outputs.InstanceChargeDetail']:
        """
        实例的计费方式等计费信息。
        """
        return pulumi.get(self, "charge_detail")

    @property
    @pulumi.getter(name="computeSpec")
    def compute_spec(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ实例的计算规格。
        """
        return pulumi.get(self, "compute_spec")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        实例的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Sequence['outputs.InstanceEndpoint']]:
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter(name="instanceDescription")
    def instance_description(self) -> pulumi.Output[builtins.str]:
        """
        实例的简单描述。
        """
        return pulumi.get(self, "instance_description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ 实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceStatus")
    def instance_status(self) -> pulumi.Output[builtins.str]:
        """
        实例状态。
        """
        return pulumi.get(self, "instance_status")

    @property
    @pulumi.getter(name="isEncrypted")
    def is_encrypted(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启了云盘加密。
        """
        return pulumi.get(self, "is_encrypted")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属的IAM项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="storageSpace")
    def storage_space(self) -> pulumi.Output[builtins.int]:
        """
        实例总存储空间。单位为 GiB。
        """
        return pulumi.get(self, "storage_space")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC的子网ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InstanceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="usedStorageSpace")
    def used_storage_space(self) -> pulumi.Output[builtins.int]:
        """
        实例已用存储空间。单位为 GiB。
        """
        return pulumi.get(self, "used_storage_space")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ WebUI管理员账号名。
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userPassword")
    def user_password(self) -> pulumi.Output[builtins.str]:
        """
        RabbitMQ WebUI管理员密码。
        """
        return pulumi.get(self, "user_password")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        支持的 RabbitMQ 版本。当前支持的版本包括：3.8.18：RabbitMQ 3.8.18 版本。
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络（VPC）ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneDescription")
    def zone_description(self) -> pulumi.Output[builtins.str]:
        """
        可用区的描述信息。
        """
        return pulumi.get(self, "zone_description")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所在的可用区 ID。对于跨 AZ 的高可用实例，此处会返回多个可用区 ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LaunchTemplateArgs', 'LaunchTemplate']

@pulumi.input_type
class LaunchTemplateArgs:
    def __init__(__self__, *,
                 launch_template_name: pulumi.Input[builtins.str],
                 default_version_number: Optional[pulumi.Input[builtins.int]] = None,
                 launch_template_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_tags: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]] = None,
                 launch_template_version: Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']] = None):
        """
        The set of arguments for constructing a LaunchTemplate resource.
        :param pulumi.Input[builtins.str] launch_template_name: 实例启动模板名称。
        :param pulumi.Input[builtins.int] default_version_number: 实例启动模板的默认版本号。
        :param pulumi.Input[builtins.str] launch_template_project_name: 实例启动模版所属项目。
        :param pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs'] launch_template_version: 实例启动模板版本信息。
        """
        pulumi.set(__self__, "launch_template_name", launch_template_name)
        if default_version_number is not None:
            pulumi.set(__self__, "default_version_number", default_version_number)
        if launch_template_project_name is not None:
            pulumi.set(__self__, "launch_template_project_name", launch_template_project_name)
        if launch_template_tags is not None:
            pulumi.set(__self__, "launch_template_tags", launch_template_tags)
        if launch_template_version is not None:
            pulumi.set(__self__, "launch_template_version", launch_template_version)

    @property
    @pulumi.getter(name="launchTemplateName")
    def launch_template_name(self) -> pulumi.Input[builtins.str]:
        """
        实例启动模板名称。
        """
        return pulumi.get(self, "launch_template_name")

    @launch_template_name.setter
    def launch_template_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "launch_template_name", value)

    @property
    @pulumi.getter(name="defaultVersionNumber")
    def default_version_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例启动模板的默认版本号。
        """
        return pulumi.get(self, "default_version_number")

    @default_version_number.setter
    def default_version_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "default_version_number", value)

    @property
    @pulumi.getter(name="launchTemplateProjectName")
    def launch_template_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模版所属项目。
        """
        return pulumi.get(self, "launch_template_project_name")

    @launch_template_project_name.setter
    def launch_template_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_project_name", value)

    @property
    @pulumi.getter(name="launchTemplateTags")
    def launch_template_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]]:
        return pulumi.get(self, "launch_template_tags")

    @launch_template_tags.setter
    def launch_template_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]]):
        pulumi.set(self, "launch_template_tags", value)

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']]:
        """
        实例启动模板版本信息。
        """
        return pulumi.get(self, "launch_template_version")

    @launch_template_version.setter
    def launch_template_version(self, value: Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']]):
        pulumi.set(self, "launch_template_version", value)


@pulumi.input_type
class _LaunchTemplateState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 default_version_number: Optional[pulumi.Input[builtins.int]] = None,
                 latest_version_number: Optional[pulumi.Input[builtins.int]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_tags: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]] = None,
                 launch_template_version: Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LaunchTemplate resources.
        :param pulumi.Input[builtins.str] created_at: 实例启动模板的创建时间。
        :param pulumi.Input[builtins.int] default_version_number: 实例启动模板的默认版本号。
        :param pulumi.Input[builtins.int] latest_version_number: 实例启动模的最新版本号。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] launch_template_name: 实例启动模板名称。
        :param pulumi.Input[builtins.str] launch_template_project_name: 实例启动模版所属项目。
        :param pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs'] launch_template_version: 实例启动模板版本信息。
        :param pulumi.Input[builtins.str] updated_at: 实例启动模板的更新时间。
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if default_version_number is not None:
            pulumi.set(__self__, "default_version_number", default_version_number)
        if latest_version_number is not None:
            pulumi.set(__self__, "latest_version_number", latest_version_number)
        if launch_template_id is not None:
            pulumi.set(__self__, "launch_template_id", launch_template_id)
        if launch_template_name is not None:
            pulumi.set(__self__, "launch_template_name", launch_template_name)
        if launch_template_project_name is not None:
            pulumi.set(__self__, "launch_template_project_name", launch_template_project_name)
        if launch_template_tags is not None:
            pulumi.set(__self__, "launch_template_tags", launch_template_tags)
        if launch_template_version is not None:
            pulumi.set(__self__, "launch_template_version", launch_template_version)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="defaultVersionNumber")
    def default_version_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例启动模板的默认版本号。
        """
        return pulumi.get(self, "default_version_number")

    @default_version_number.setter
    def default_version_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "default_version_number", value)

    @property
    @pulumi.getter(name="latestVersionNumber")
    def latest_version_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        实例启动模的最新版本号。
        """
        return pulumi.get(self, "latest_version_number")

    @latest_version_number.setter
    def latest_version_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "latest_version_number", value)

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @launch_template_id.setter
    def launch_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_id", value)

    @property
    @pulumi.getter(name="launchTemplateName")
    def launch_template_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板名称。
        """
        return pulumi.get(self, "launch_template_name")

    @launch_template_name.setter
    def launch_template_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_name", value)

    @property
    @pulumi.getter(name="launchTemplateProjectName")
    def launch_template_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模版所属项目。
        """
        return pulumi.get(self, "launch_template_project_name")

    @launch_template_project_name.setter
    def launch_template_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_project_name", value)

    @property
    @pulumi.getter(name="launchTemplateTags")
    def launch_template_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]]:
        return pulumi.get(self, "launch_template_tags")

    @launch_template_tags.setter
    def launch_template_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateLaunchTemplateTagArgs']]]]):
        pulumi.set(self, "launch_template_tags", value)

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']]:
        """
        实例启动模板版本信息。
        """
        return pulumi.get(self, "launch_template_version")

    @launch_template_version.setter
    def launch_template_version(self, value: Optional[pulumi.Input['LaunchTemplateLaunchTemplateVersionArgs']]):
        pulumi.set(self, "launch_template_version", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板的更新时间。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("bytepluscc:ecs/launchTemplate:LaunchTemplate")
class LaunchTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_version_number: Optional[pulumi.Input[builtins.int]] = None,
                 launch_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateLaunchTemplateTagArgs', 'LaunchTemplateLaunchTemplateTagArgsDict']]]]] = None,
                 launch_template_version: Optional[pulumi.Input[Union['LaunchTemplateLaunchTemplateVersionArgs', 'LaunchTemplateLaunchTemplateVersionArgsDict']]] = None,
                 __props__=None):
        """
        实例启动模板是一系列实例配置信息的集合，用于快速购买实例。在模板中，您可以存储除密码外的全部配置信息，包括密钥对、计算规格、云盘、网络等，如果配置信息均有效，便可以一键成功购买实例，无需进行重复配置。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/launchTemplate:LaunchTemplate example "launch_template_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] default_version_number: 实例启动模板的默认版本号。
        :param pulumi.Input[builtins.str] launch_template_name: 实例启动模板名称。
        :param pulumi.Input[builtins.str] launch_template_project_name: 实例启动模版所属项目。
        :param pulumi.Input[Union['LaunchTemplateLaunchTemplateVersionArgs', 'LaunchTemplateLaunchTemplateVersionArgsDict']] launch_template_version: 实例启动模板版本信息。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LaunchTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        实例启动模板是一系列实例配置信息的集合，用于快速购买实例。在模板中，您可以存储除密码外的全部配置信息，包括密钥对、计算规格、云盘、网络等，如果配置信息均有效，便可以一键成功购买实例，无需进行重复配置。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/launchTemplate:LaunchTemplate example "launch_template_id"
        ```

        :param str resource_name: The name of the resource.
        :param LaunchTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LaunchTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_version_number: Optional[pulumi.Input[builtins.int]] = None,
                 launch_template_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateLaunchTemplateTagArgs', 'LaunchTemplateLaunchTemplateTagArgsDict']]]]] = None,
                 launch_template_version: Optional[pulumi.Input[Union['LaunchTemplateLaunchTemplateVersionArgs', 'LaunchTemplateLaunchTemplateVersionArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LaunchTemplateArgs.__new__(LaunchTemplateArgs)

            __props__.__dict__["default_version_number"] = default_version_number
            if launch_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'launch_template_name'")
            __props__.__dict__["launch_template_name"] = launch_template_name
            __props__.__dict__["launch_template_project_name"] = launch_template_project_name
            __props__.__dict__["launch_template_tags"] = launch_template_tags
            __props__.__dict__["launch_template_version"] = launch_template_version
            __props__.__dict__["created_at"] = None
            __props__.__dict__["latest_version_number"] = None
            __props__.__dict__["launch_template_id"] = None
            __props__.__dict__["updated_at"] = None
        super(LaunchTemplate, __self__).__init__(
            'bytepluscc:ecs/launchTemplate:LaunchTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            default_version_number: Optional[pulumi.Input[builtins.int]] = None,
            latest_version_number: Optional[pulumi.Input[builtins.int]] = None,
            launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
            launch_template_name: Optional[pulumi.Input[builtins.str]] = None,
            launch_template_project_name: Optional[pulumi.Input[builtins.str]] = None,
            launch_template_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateLaunchTemplateTagArgs', 'LaunchTemplateLaunchTemplateTagArgsDict']]]]] = None,
            launch_template_version: Optional[pulumi.Input[Union['LaunchTemplateLaunchTemplateVersionArgs', 'LaunchTemplateLaunchTemplateVersionArgsDict']]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'LaunchTemplate':
        """
        Get an existing LaunchTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: 实例启动模板的创建时间。
        :param pulumi.Input[builtins.int] default_version_number: 实例启动模板的默认版本号。
        :param pulumi.Input[builtins.int] latest_version_number: 实例启动模的最新版本号。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] launch_template_name: 实例启动模板名称。
        :param pulumi.Input[builtins.str] launch_template_project_name: 实例启动模版所属项目。
        :param pulumi.Input[Union['LaunchTemplateLaunchTemplateVersionArgs', 'LaunchTemplateLaunchTemplateVersionArgsDict']] launch_template_version: 实例启动模板版本信息。
        :param pulumi.Input[builtins.str] updated_at: 实例启动模板的更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LaunchTemplateState.__new__(_LaunchTemplateState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["default_version_number"] = default_version_number
        __props__.__dict__["latest_version_number"] = latest_version_number
        __props__.__dict__["launch_template_id"] = launch_template_id
        __props__.__dict__["launch_template_name"] = launch_template_name
        __props__.__dict__["launch_template_project_name"] = launch_template_project_name
        __props__.__dict__["launch_template_tags"] = launch_template_tags
        __props__.__dict__["launch_template_version"] = launch_template_version
        __props__.__dict__["updated_at"] = updated_at
        return LaunchTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="defaultVersionNumber")
    def default_version_number(self) -> pulumi.Output[builtins.int]:
        """
        实例启动模板的默认版本号。
        """
        return pulumi.get(self, "default_version_number")

    @property
    @pulumi.getter(name="latestVersionNumber")
    def latest_version_number(self) -> pulumi.Output[builtins.int]:
        """
        实例启动模的最新版本号。
        """
        return pulumi.get(self, "latest_version_number")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="launchTemplateName")
    def launch_template_name(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板名称。
        """
        return pulumi.get(self, "launch_template_name")

    @property
    @pulumi.getter(name="launchTemplateProjectName")
    def launch_template_project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模版所属项目。
        """
        return pulumi.get(self, "launch_template_project_name")

    @property
    @pulumi.getter(name="launchTemplateTags")
    def launch_template_tags(self) -> pulumi.Output[Sequence['outputs.LaunchTemplateLaunchTemplateTag']]:
        return pulumi.get(self, "launch_template_tags")

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> pulumi.Output['outputs.LaunchTemplateLaunchTemplateVersion']:
        """
        实例启动模板版本信息。
        """
        return pulumi.get(self, "launch_template_version")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板的更新时间。
        """
        return pulumi.get(self, "updated_at")

